use neo_entity::users::{self, Entity as User};
use sea_orm_migration::prelude::*;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(User)
                    .if_not_exists()
                    .col(
                        ColumnDef::new(users::Column::Uuid)
                            .uuid()
                            .primary_key()
                            .not_null(),
                    )
                    .col(ColumnDef::new(users::Column::UserId).string().not_null())
                    .col(
                        ColumnDef::new(users::Column::DisplayName)
                            .string()
                            .not_null(),
                    )
                    .col(
                        ColumnDef::new(users::Column::PasswordHash)
                            .string()
                            .not_null(),
                    )
                    .to_owned(),
            )
            .await?;
        manager
            .create_index(
                Index::create()
                    .name("user_id_index")
                    .table(User)
                    .col(users::Column::UserId)
                    .to_owned(),
            )
            .await
    }
}
