use neo_entity::events::{self, Entity as Event};
use sea_orm_migration::prelude::*;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(Event)
                    .if_not_exists()
                    .col(
                        ColumnDef::new(events::Column::Uuid)
                            .uuid()
                            .primary_key()
                            .not_null(),
                    )
                    .col(ColumnDef::new(events::Column::RoomUuid).uuid().not_null())
                    .col(ColumnDef::new(events::Column::Type).string().not_null())
                    .col(ColumnDef::new(events::Column::StateKey).string())
                    .col(ColumnDef::new(events::Column::SenderUuid).uuid().not_null())
                    .col(
                        ColumnDef::new(events::Column::OriginServerTs)
                            .integer()
                            .not_null(),
                    )
                    .col(ColumnDef::new(events::Column::Content).json().not_null())
                    .to_owned(),
            )
            .await?;
        manager
            .create_index(
                Index::create()
                    .name("room_uuid_index")
                    .table(Event)
                    .col(events::Column::RoomUuid)
                    .to_owned(),
            )
            .await?;
        manager
            .create_index(
                Index::create()
                    .name("type_index")
                    .table(Event)
                    .col(events::Column::Type)
                    .to_owned(),
            )
            .await?;
        manager
            .create_index(
                Index::create()
                    .name("state_key_index")
                    .table(Event)
                    .col(events::Column::StateKey)
                    .to_owned(),
            )
            .await?;
        manager
            .create_index(
                Index::create()
                    .name("type_state_key_index")
                    .table(Event)
                    .col(events::Column::Type)
                    .col(events::Column::StateKey)
                    .to_owned(),
            )
            .await
    }
}
